Library interface — CALCEPH - Fortran 77/90/95 language 3.4.1 documentation

# Library interface

## A simple example program

The following example program shows the typical usage of the Fortran 77/90/95 interface.

Other examples using the Fortran 77/90/95 interface can be found in the directory examples of the library sources.

    program F90example
        implicit none
        include 'f90calceph.h'
        integer res
        double precision AU
        integer*8 :: peph

        res = f90calceph_open(peph, "example1.dat")
        if (res.eq.1) then
          write (*,*) "The ephemeris is already opened"
          if (f90calceph_getconstant(peph, "AU", AU).eq.1) then
                write (*,*) "AU=", AU
          endif
          call f90calceph_close(peph)
          write (*,*) "The ephemeris is already closed"
        endif
    stop
    end

## Headers and Libraries

It is designed to work with Fortran compilers compliant with the Fortran 77, 90 or 95 standard with wrappers. All declarations are implicit, so you should take care about the types of the arguments. All functions are prefixed by f90. This interface is only provided as compatibility layer and have a small overhead due to the wrappers. So if you have a fortran compiler compliant with 2003 standard, you should use the fortran 2003 interface of this library.

All declarations needed to use CALCEPH Library are collected in the header file `f90calceph.h`. It is designed to work with Fortran compilers compliant with the Fortran 77 , 90 or 95 standard.

You should include that file in every subroutine or function in any program using the CALCEPH library:

    include 'f90calceph.h'

### Compilation on a Unix-like system

> All programs using CALCEPH must link against the `libcalceph` library. On Unix-like system this can be done with -lcalceph, for example

> >     gfortran -I/usr/local/include myprogram.f -o myprogram  -lcalceph

> If CALCEPH Library has been installed to a non-standard location then it may be necessary to use -I and -L compiler options to point to the right directories, and some sort of run-time path for a shared library.

### Compilation on a Windows system

> All programs using CALCEPH must link against the `libcalceph.lib`. On Windows system this can be done with libcalceph.lib, for example

> >     gfortran.exe /out:myprogram.exe myprogram.f libcalceph.lib

> If CALCEPH Library has been installed to a non-standard location then it may be necessary to use /I and /LIBPATH: compiler options to point to the right directories.

## Types

## Constants

The following constants are defined in the file `f90calceph.h`.

`CALCEPH_MAX_CONSTANTNAME` [integer]

This integer defines the maximum number of characters, including the trailing '\0', that the name of a constant, available from the ephemeris file, could contain.

`CALCEPH_MAX_CONSTANTVALUE` [integer]

This integer defines the maximum number of characters, including the trailing '\0', that the value of a constant, available from the ephemeris file, could contain if the value is stored as a string of characters.

`CALCEPH_VERSION_MAJOR` [integer]

This integer constant defines the major revision of this library. It can be used to distinguish different releases of this library.

`CALCEPH_VERSION_MINOR` [integer]

This integer constant defines the minor revision of this library. It can be used to distinguish different releases of this library.

`CALCEPH_VERSION_PATCH` [integer]

This integer constant defines the patch level revision of this library. It can be used to distinguish different releases of this library.

`CALCEPH_VERSION_STRING` [character(len=*)]

This string is the version of the library, which can be compared to the result of calceph_getversion to check at run time if the header file and library used match:

Note: Obtaining different strings is not necessarily an error, as in general, a program compiled with some old CALCEPH version can be dynamically linked with a newer CALCEPH library version (if allowed by the operating system).

`CALCEPH_ASTEROID` [integer]

This integer defines the offset value for the asteroids that must be used as target or center for the computation functions, such as `f90calceph_compute()`.

The following constants specify in which units are expressed the output of the computation functions, such as `f90calceph_compute_unit()` :

`CALCEPH_UNIT_AU` [integer]

This integer defines that the unit of the positions and velocities is expressed in astronomical unit.

`CALCEPH_UNIT_KM` [integer]

This integer defines that the unit of the positions and velocities is expressed in kilometer.

`CALCEPH_UNIT_DAY` [integer]

This integer defines that the unit of the velocities or the quantity TT-TDB or TCG-TCB is expressed in day (one day=86400 seconds).

`CALCEPH_UNIT_SEC` [integer]

This integer defines that the unit of the velocities or the quantity TT-TDB or TCG-TCB is expressed in second.

`CALCEPH_UNIT_RAD` [integer]

This integer defines that the unit of the angles is expressed in radian.

`CALCEPH_OUTPUT_EULERANGLES` [integer]

This integer defines that the output array contains the euler angles.

`CALCEPH_OUTPUT_NUTATIONANGLES` [integer]

This integer defines that the output array contains the nutation angles.

`CALCEPH_USE_NAIFID` [integer]

This integer defines that the NAIF identification numbers are used as target or center for the computation functions, such as `f90calceph_compute_unit()`.